﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using C1.Win.Chart;
using AxisGroupingDemo.Data.Model;

namespace AxisGroupingDemo.Samples
{
    public partial class CategoricalAxisGrouping : UserControl
    {
        private FlexChart flexChart1;
        private NumericUpDown groupLevels;
        private CheckBox chkFlatData;
        private Axis categoryAxis;
            
        public CategoricalAxisGrouping()
        {
            InitializeComponent();
            InitializeControls();
            SetupChart();
            chkFlatData.Checked = true;
        }

        private void SetupChart()
        {
            flexChart1.Series.Clear();
            flexChart1.BindingX = "Name";
            flexChart1.Header.Content = "Employee Distribution By Region";
            flexChart1.Header.Style.Font = new System.Drawing.Font(flexChart1.Font.FontFamily, 14);
            flexChart1.ToolTip.Content = "{Continent}\n{Country}\n{y}";

            flexChart1.AxisY.Title = "Number of Employees";
            flexChart1.AxisX.LabelAngle = 90;
            flexChart1.Series.Add(new C1.Win.Chart.Series
            {
                Binding = "Value"
            });

            flexChart1.DataSource = Unit.Data();
            categoryAxis = flexChart1.AxisX;
            categoryAxis.GroupNames = "";
            categoryAxis.GroupItemsPath = null;
            categoryAxis.GroupSeparator = C1.Chart.AxisGroupSeparator.Grid;

        }

        private void InitializeControls()
        {
            baseSample1.lblTitle.Text = Properties.Resources.CategoricalAxisTitle;
            baseSample1.tbDescription.Text = Properties.Resources.CategoricalAxisDesc;

            var lblGroupLevels = new Label { Text = "Group Levels", TextAlign = ContentAlignment.MiddleCenter };

            groupLevels = new NumericUpDown
            {
                Text = "Group Levels",
                Minimum = 0,
                Maximum = 2,
                Value = 1
            };

            chkFlatData = new CheckBox
            {
                Text = "View Flat Data"
            };

            flexChart1 = baseSample1.flexChart1;
            groupLevels.ValueChanged += OnGroupLevelChanged;
            chkFlatData.CheckedChanged += OnFlatDataCheckChanged;

            baseSample1.pControls.Controls.Add(lblGroupLevels);
            baseSample1.pControls.Controls.Add(groupLevels);
            baseSample1.pControls.Controls.Add(chkFlatData);

        }

        private void OnFlatDataCheckChanged(object sender, EventArgs e)
        {
            if (chkFlatData.Checked)
            {
                GroupFlatData();
            }
            else
            {
                GroupHierarchicalData();
            }
            flexChart1.Rebind();
        }

        private void OnGroupLevelChanged(object sender, EventArgs e)
        {
            flexChart1.BeginUpdate();
            if (chkFlatData.Checked)
            {
                GroupFlatData();
            }
            else
                GroupHierarchicalData();

            flexChart1.EndUpdate();
        }

        private void GroupHierarchicalData()
        {
            switch (groupLevels.Value)
            {
                case 0:
                default:
                    flexChart1.DataSource = HierarchicalUnit.SingleLevelData();
                    categoryAxis.GroupNames = null;
                    categoryAxis.GroupItemsPath = null;
                    break;
                case 1:
                    flexChart1.DataSource = HierarchicalUnit.SingleLevelData();
                    categoryAxis.GroupNames = "Country";
                    categoryAxis.GroupItemsPath = "Items";
                    break;
                case 2:
                    flexChart1.DataSource = HierarchicalUnit.Data();
                    categoryAxis.GroupNames = "Continent,Country";
                    categoryAxis.GroupItemsPath = "Items";
                    break;
            }
        }

        private void GroupFlatData()
        {
            flexChart1.DataSource = Unit.Data();
            categoryAxis.GroupItemsPath = null;
            switch (groupLevels.Value)
            {
                case 0:
                default:
                    categoryAxis.GroupNames = null;
                    break;
                case 1:
                    categoryAxis.GroupNames = "Country";
                    break;
                case 2:
                    categoryAxis.GroupNames = "Continent,Country";
                    break;
            }
        }

}
}
