﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using C1.Win.Chart;
using C1.Chart;
using AxisGroupingDemo.Data;
using AxisGroupingDemo.Data.Model;

namespace AxisGroupingDemo.Samples
{
    public partial class NumericalAxisGrouping : UserControl
    {
        private FlexChart flexChart1;
        private ComboBox cbState;
        private NumericUpDown groupLevels;

        public NumericalAxisGrouping()
        {
            InitializeComponent();
            this.Load += (s, e) =>
             {
                 InitializeControls();
                 SetupChart();
                 cbState.SelectedIndex = 1;
             };
        }

        private void SetupChart()
        {
            flexChart1.Series.Clear();
            flexChart1.BindingX = "Name";

            var pm10 = new Series
            {
                Name = "PM10",
                Binding = "PM10"
            };
            flexChart1.Series.Add(pm10);
            flexChart1.AxisY.GroupProvider = new NumericGroupProvider() { PollutantType = NumericGroupProvider.Pollutant.PM10 };
            flexChart1.AxisY.GroupSeparator = AxisGroupSeparator.Horizontal;
            flexChart1.AxisY.GroupTitleAlignment = AxisLabelAlignment.Bottom;
            flexChart1.AxisY.AxisLine = true;
            flexChart1.AxisX.LabelAngle = -45;
            flexChart1.AxisY.Title = "Air Quality Index based on PM10 concentration";
            flexChart1.Header.Style.Font = new Font(flexChart1.Font.FontFamily, 14);

        }

        private void InitializeControls()
        {
            baseSample1.lblTitle.Text = Properties.Resources.NumericalAxisTitle;
            baseSample1.tbDescription.Text = Properties.Resources.NumericalAxisDesc; 

            flexChart1 = baseSample1.flexChart1;

            var data = DataService.GetAQIData();

            cbState = new ComboBox
            {
                DataSource = data,
                DisplayMember = "Name"
            };
            cbState.SelectedIndexChanged += (s, e) =>
            {
                var selectedItem = cbState.SelectedItem as State;
                UpdateChart(selectedItem);
            };

            var lblGroupLevels = new Label { Text = "Group Levels",TextAlign = ContentAlignment.MiddleCenter };
            groupLevels = new NumericUpDown
            {
                Minimum = 0,
                Maximum = 1,
                Value = 1
            };

            groupLevels.ValueChanged += (s, e) =>
            {
                var grp = flexChart1.AxisY.GroupProvider as NumericGroupProvider;
                grp.Levels = (int)groupLevels.Value;
                flexChart1.Refresh();
            };

            baseSample1.pControls.Controls.Add(lblGroupLevels);
            baseSample1.pControls.Controls.Add(groupLevels);
            baseSample1.pControls.Controls.Add(cbState);
        }

        private void UpdateChart(State state)
        {
            flexChart1.DataSource = state.Counties;
            flexChart1.Header.Content = string.Format("{0} 2017: Concentration of PM10 particles", state.Name);
        }
    }

    public class NumericGroupProvider : IAxisGroupProvider
    {
        public enum Pollutant
        {
            PM10,
            PM25
        }

        public int Levels { get; set; }

        public NumericGroupProvider()
        {
            Levels = 1;
        }

        public Pollutant PollutantType { get; set; }

        public int GetLevels(IRange range)
        {
            return Levels;
        }

        public IList<IRange> GetRanges(IRange range, int level)
        {
            var ranges = new List<IRange>();
            if (level == 1)
            {
                if (PollutantType == Pollutant.PM10)
                {
                    ranges.Add(new DoubleRange("Good", 0, 54));
                    ranges.Add(new DoubleRange("Moderate", 55, 154));
                    ranges.Add(new DoubleRange("Unhealthy", 155, 354));
                    ranges.Add(new DoubleRange("Very Unhealthy", 355, 424));
                    ranges.Add(new DoubleRange("Hazardous", 425, double.PositiveInfinity));
                }
                else
                {
                    ranges.Add(new DoubleRange("Good", 0, 12));
                    ranges.Add(new DoubleRange("Moderate", 12.1, 35.4));
                    ranges.Add(new DoubleRange("Unhealthy", 35.5, 150.4));
                    ranges.Add(new DoubleRange("Very Unhealthy", 150.5, 250.4));
                    ranges.Add(new DoubleRange("Hazardous", 250.5, double.PositiveInfinity));
                }
            }
            return ranges;
        }
    }
}
